﻿<?php	
	/*
		Dieses Script erwartet Wetterdaten wie sie von der Wetterstation "HP1000SE PRO" (z.B. von froggit) gesendet werden können.
		Dazu muss in der Wetterstation die Einstellung Setup->Weather Server->Customized aktiviert werden. Protokolltyp "Same As Ecowitt".
		Hostname: Adresse eines eigenen Webservers. Path: ein selbst erzeugtes Verzeichnis auf dem Server. 
		In dem Verzeichnis wird nur diese Datei benötigt.

		Für Protokolldatei und CSV-Datei sollten (wenn gewünscht) die entsprechenden Unterverzeichnisse erzeugt werden. Andernfalls die
		Einträge "$csvfile" und/oder "$logfile" anpassen oder leer (="") machen.
		
		Zum Eintragen in eine MySQL-Datenbank müssen die Einstellungen $srv, $db, $usr, $pw, $tbl (siehe unten) korrekt ausgefüllt werden.
		
		Zum Testen der Funktion kann die Adresse 
		http://<Hostname>/<Path>/index.php
		im Browser aufgerufen werden. 
		Dann wird je nach gültigen Einträgen 
			- eine Log-Datei
			- eine CSV-Datei
			- eine Datenbanktabelle "wetter" mit einem Datensatz 
		erzeugt und ein "Dummy"-Datensatz im Browser angezeigt.
		
	*/

	//wenn einer der folgenden Werte leer ist (""), wird nicht in die Datenbank geschrieben
	$srv = "localhost"; //Servername/-adresse
	$db = "wetter";     //Datenbankname
	$usr = "wetter";		//Benutzer-/Anmeldename
	$pw = "wetter"; //Passwort
	$tbl = "wetter";    //Name der Tabelle für die Wetterdaten

	//CSV-Datei wird geschrieben, wenn $logfile != "" (leer))
	$csvfile = 'csv/'.date('Y-m-d').'.csv';
			
	//Protokollierung wird geschrieben, wenn $logfile != "" (leer)
	$logfile = 'log/'.date('Y-m-d').'.log';

	
	
	if ($logfile != "")
	{
		$l = fopen($logfile, 'a');
		fwrite($l, $_SERVER['REMOTE_ADDR'].':'.print_r($_POST, true));
	}
	else	
		$l = false;
	
	if ($csvfile != "")
	{
		if (!file_exists($csvfile)) {
			//wenn neue Log-Datei, schreib' Spaltenüberschriften.
			$f = fopen($csvfile, 'a');
			fwrite($f, '"Timestamp","UTC","Temp Innen","Feuchte Innen","Temp Außen","Feuchte Außen","Luftdruck",'.
							'"Wind Richtung","V Wind","V Wind Bö","Solarleistung","UV-Intensität","Regenrate",'.
							'"Regen aktuell","Regen/Tag","Regen/Woche","Regen/Monat","Regen/Jahr",'
							.'"Batterie 1","Batterie 2","Sender-IP"'.PHP_EOL);
		}
		else {
			$f = fopen($csvfile, 'a');
		}
	}
	else
		$l = false;
	
	//Alle Werte werden in "imperial" (amerikanischen) Einheiten übertragen.
	//Übertrage alle POST-Parameter in variable, ggf. mit Konvertierungen.
	$p = $_POST;
	$d = "'".($p['dateutc'] ?: @date('Y-m-d H:i:s'))."'";
	$ti = round(($p['tempinf']?:0 - 32)*5/9, 1);
	$fi = $p['humidityin']?:0;
	$ta = round(($p['tempf'] - 32)*5/9, 1);
	$fa = $p['humidity']?:0;
	$druck = round($p['baromabsin']?:0/0.029529980164712, 1);
	$wr = $p['winddir']?:0;
	$ws = round(($p['windspeedmph']?:0)  * 0.44704, 1);
	$wsg = round(($p['windgustmph']?:0) * 0.44704, 1);
	$sr = $p['solarradiation']?:0;
	$uv = $p['uv']?:0;
	$rnrate = $p['rainratein']?:0 * 25.4;
	$rnevt = $p['eventrainin']?:0 * 25.4;
	$rndy = round($p['dailyrainin']?:0 * 25.4, 1);
	$rnwk = round($p['weeklyrainin']?:0 * 25.4, 1);
	$rnmth = round($p['monthlyrainin']?:0 * 25.4, 1);
	$rnyr = round($p['yearlyrainin']?:0 * 25.4, 1);
	
	$bat1 = $p['wh68batt']?:0;
	$bat2 = $p['wh40batt']?:0;
	$sip = "'{$_SERVER["REMOTE_ADDR"]}'";

	$str = @date("'d.m.Y H:i:s'")
					.",$d,$ti,$fi,$ta,$fa,$druck,$wr,$ws,$wsg,$sr,$uv,$rnrate,$rnevt,$rndy,$rnwk,$rnmth,$rnyr,$bat1,$bat2,$sip"
					.PHP_EOL;
	if ($f)
	{
		$fstr = str_replace("'", '"', $str);
		fwrite($f, $fstr);
	}

	echo $str;
	
	$chktable = <<<EOT
		CREATE TABLE if not exists $tbl (
			ts TIMESTAMP DEFAULT current_timestamp(),
			dateutc DATETIME DEFAULT NULL,
			luftdruck INT(11) DEFAULT NULL,
			temperatur1 DECIMAL(10, 2) DEFAULT NULL,
			temperatur2 DECIMAL(10, 2) DEFAULT NULL,
			feuchte1 INT(11) DEFAULT NULL,
			feuchte2 INT(11) DEFAULT NULL,
			v_wind_boe DECIMAL(10, 2) DEFAULT NULL,
			windrichtung INT(11) DEFAULT NULL,
			v_wind DECIMAL(10, 2) DEFAULT NULL,
			sonne DECIMAL(10, 2) DEFAULT NULL,
			uv DECIMAL(10, 2) DEFAULT NULL,
			regen_rate DECIMAL(10, 6) DEFAULT NULL,
			regen_ereignis DECIMAL(10, 6) DEFAULT NULL,
			regen_tag DECIMAL(10, 6) UNSIGNED DEFAULT NULL,
			regen_woche DECIMAL(10, 0) DEFAULT NULL,
			regen_monat DECIMAL(10, 3) DEFAULT NULL,
			regen_jahr DECIMAL(10, 3) DEFAULT NULL,
			wh68batt DECIMAL(10, 3) DEFAULT NULL,
			wh40batt DECIMAL(10, 3) DEFAULT NULL,
			sender_ip VARCHAR(20) DEFAULT NULL,
			PRIMARY KEY (ts)
		)
		CHARACTER SET utf8
		COLLATE utf8_general_ci;
EOT;
		
	
	$qry = <<<EOT
		insert into $tbl (
				dateutc, luftdruck, temperatur1, temperatur2, feuchte1, feuchte2
				, windrichtung, v_wind, v_wind_boe
				, sonne, uv, regen_rate, regen_ereignis
				, regen_tag, regen_woche, regen_monat, regen_jahr
				, wh68batt, wh40batt, sender_ip)
			values (
				$d, $druck, $ti, $ta, $fi, $fa
				, $wr, $ws, $wsg
				, $sr, $uv, $rnrate, $rnevt
				, $rndy, $rnwk, $rnmth, $rnyr
				, $bat1, $bat2, $sip
				);
EOT;
				
//	echo($qry.PHP_EOL);
	if ($srv!="" && $usr!="" && $pw!="" && $db !="")
  {
		$cn = new mysqli($srv, $usr, $pw, $db);
		if (!$conn->connect_error) {
			$rs = $cn->query($chktable);
			if ($rs)
				$rs = $cn->query($qry);
			if (!$rs)
			{
				if ($l)
					fwrite($l, "Query Failed".PHP_EOL);
				echo PHP_EOL."Query Failed".PHP_EOL;
			}
		}	
	}
	if ($l)
		fclose($l);
	
	if ($f)
		fclose($f);

?>